@@ -2,19 +2,17 @@
 
 
 #' pickMean
-#' 
+#'
 #' pick mean method
-#' 
+#'
 #' This method mainly implement pick mean method
-#' 
+#'
 #' @param env.stack a \code{rasterStack} object that contain the environment variable
-#' @param subset subset is a string \code{vector} that contain environment variables names which into calculate, if NULL that all var in env.stack will calculate. 
+#' @param subset subset is a string \code{vector} that contain environment variables names which into calculate, if NULL that all var in env.stack will calculate.
 #' @param stack stack is an option that if you want not compose them togethor (result return as a \code{rasterStack}). Default is FALSE
 #' @return \code{rasterLayer} or \code{rasterStack} if stack is set to TRUE
 #' @references Jiménez-Valverde, A., & Lobo, J. M. (2007). Threshold criteria for conversion of probability of species presence to either–or presence–absence. Acta oecologica, 31(3), 361-369.
 #' @encoding utf-8
-#' @importFrom raster cellStats
-#' @importFrom raster stackApply
 #' @export
 #' @examples
 #' # load the sdmvspecies library
@@ -54,7 +52,7 @@ pickMean <- function(env.stack, subset=NULL, stack=FALSE) {
     }
 
     # TODO:here used mclapply but not given core.number
-    species.list <- mclapply(X=env.names, FUN=.pickMean, env.stack)
+    species.list <- parallel::mclapply(X=env.names, FUN=.pickMean, env.stack)
 
     if (!stack) {
         species.stack <- stack(species.list)
@@ -62,12 +60,13 @@ pickMean <- function(env.stack, subset=NULL, stack=FALSE) {
         threshold <- length(env.names)
         species.layer <- species.layer >= threshold
         return(species.layer)
-    } else {        
+    } else {
         species.layer <- env.stack[[env.names[1]]]
         col.number <- length(species.list)
         species.stack <- stack()
         for (col.index in 1:col.number) {
-            species.raster <- setValues(species.layer, as.vector(species.list[[col.index]]))
+            # species.raster <- setValues(species.layer, as.vector(species.list[[col.index]]))
+            species.raster <- setValues(species.layer, getValues(species.list[[col.index]]))
             species.stack <- stack(species.stack, species.raster)
         }
         names(species.stack) <- env.names
@@ -84,4 +83,4 @@ pickMean <- function(env.stack, subset=NULL, stack=FALSE) {
     factors.max.end <- factors.mean+factors.sd
     result.layer <- ((env.layer >= factors.min.end) & (env.layer <= factors.max.end))
     return(result.layer)
-}
\ No newline at end of file
+}
